@@ -2,7 +2,10 @@
 #'
 #' @description Performs pairwise two-sample robust tests across groups
 #'              with matrix output.
-#' 
+#'              
+#' @param formula A formula indicating the measurement variable and
+#'                the grouping variable. e.g. y ~ group.
+#' @param data   The data frame to use.                
 #' @param x      The response variable as a vector.
 #' @param g      The grouping variable as a vector.
 #' @param est    Estimate used for group comparisons.
@@ -15,7 +18,9 @@
 #' @param ...    Additional arguments passed to
 #'               \code{\link{pb2gen}}.               
 #'             
-#' @details 
+#' @details The input should include either \code{formula} and \code{data};
+#'          or \code{x}, and \code{g}.
+#'          
 #'          The \code{WRS2} package provides functions for robust estimation
 #'          and hypothesis testing.  This function invokes the
 #'          \code{pb2gen} to make pairwise comparisons among
@@ -33,13 +38,19 @@
 #'         A matrix of p-values;
 #'         the p-value adjustment method;
 #'         a matrix of adjusted p-values. 
-#'         
+#'
+#' @note    The parsing of the formula is simplistic. 
+#'          The first variable on the
+#'          left side is used as the measurement variable.  
+#'          The first variable on the
+#'          right side is used for the grouping variable.
+#'
 #' @examples
 #' data(PoohPiglet)
-#' PoohPiglet$Speaker = factor(PoohPiglet$Speaker, 
-#'                             levels=c("Pooh", "Tigger", "Piglet"))               
-#' PT = pairwiseRobustMatrix(x      = PoohPiglet$Likert,
-#'                           g      = PoohPiglet$Speaker,
+#' PoohPiglet$Speaker = factor(PoohPiglet$Speaker,
+#'                      levels = c("Pooh", "Tigger", "Piglet"))              
+#' PT = pairwiseRobustMatrix(Likert ~ Speaker,
+#'                           data   = PoohPiglet,
 #'                           method = "fdr")$Adjusted
 #' PT                           
 #' library(multcompView)
@@ -54,8 +65,14 @@
 #' @export
 
 pairwiseRobustMatrix = 
-  function(x, g, est="mom", nboot=599, method="fdr", ...)
+  function(formula=NULL, data=NULL,
+           x=NULL, g=NULL, 
+           est="mom", nboot=599, method="fdr", ...)
   {
+  if(!is.null(formula)){
+    x  = eval(parse(text=paste0("data","$",all.vars(formula[[2]])[1])))
+    g  = eval(parse(text=paste0("data","$",all.vars(formula[[3]])[1])))
+    }    
   if(!is.factor(g)){g=factor(g)}
   n = length(levels(g))
   N = n*n
